@@ -40,6 +40,8 @@ class GraphicsScene : public QGraphicsScene
 			delete fl;
 			qDeleteAll(m_grid.begin(), m_grid.end() );
 		};
+		void twoPlayers();
+		int numberPlayers();
 		void changeLevel();
 		void restartGame();
 // 		void askUserName();
@@ -52,6 +54,7 @@ class GraphicsScene : public QGraphicsScene
 		void endFinalLine();
 		void CPUMove();
 		bool checkFinish();
+		void updatePlayerText();
 		virtual void mousePressEvent(QGraphicsSceneMouseEvent* event);
 		bool algunaCasillaLibre();
 		void cleanAll();
@@ -83,6 +86,8 @@ class GraphicsScene : public QGraphicsScene
 		QGraphicsTextItem* m_winner;
 		QGraphicsTextItem* m_restart;
 // 		QString userName;
+		int players;
+		int movePlayer;
 		int ganador;
 		bool endGame;
 		int win;
