@@ -32,11 +32,13 @@ class GraphicsView : public QGraphicsView
 		~GraphicsView();
 		
 		virtual void showEvent (QShowEvent* event);
+		void twoPlayers();
 		void changeLevel();
 		void restartGame();
 // 		void askUserName();
 		void statistics();
 		void changeShape();
+		int numberPlayers();
 	private:
 		GraphicsScene* scene;
 };
