@@ -23,6 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "graphicsview.h"
 
 #include <QMainWindow>
+#include <QAction>
 
 class MainWindow : public QMainWindow
 {
@@ -31,6 +32,7 @@ class MainWindow : public QMainWindow
 		MainWindow ( QWidget* parent = 0 );
 		~MainWindow ();
 	private slots:
+		void twoPlayers();
 		void changeLevel();
 		void restartGame();
 // 		void askUserName();
@@ -39,7 +41,10 @@ class MainWindow : public QMainWindow
 // 		void showEvent(QShowEvent* event);
 	private:
 		GraphicsView* gv;
-		bool firstTime;
+// 		bool firstTime;
+		QAction* optionPlayers;
+		QAction* optionLevel;
+		QAction* optionStatistics;
 };
 
 #endif // MAINWINDOW_H
